THE BOOST MPL LIBRARY: Miscellaneous

Front Page / Changelog & History / Changes in Boost 1.32.0 Release / Miscellaneous

# Miscellaneous

1. `vector` has been re-implemented to support constant-time insertion at both the beginning and the end. For example, this is now well-formed for a vector `v`:

       typedef push_back<v,int>::type v1;
       typedef push_front<v1,int>::type v2;

2. The interfaces of some sequence building algorithms such as `copy` have been changed. Please see the reference manual for the details of the new interface.